# Integrated Cognative User Assistance 2

icua2 is an experimental platform that supports the development of AI-based user assistants. The platform is written in Python and is based on the multi-agent simulation platform [Star Ray](https://github.com/dicelab-rhul/star-ray) (**S**imulation **T**estbed for **A**gent **R**esearch [**ray**](https://www.ray.io/)). 

## Documentation 

Documentation is coming soon, for now see the first instance of an icua2 system: a fully customisable [mabtii clone](https://dicelab-rhul.github.io/matbii/latest/) which has been built to support experiments in human factors research.
